@@ -489,26 +489,12 @@ impl_show_properties (RBMediaPlayerSource *source, GtkWidget *info_box, GtkWidge
 	GtkBuilder *builder;
 	GtkWidget *widget;
 	GObject *plugin;
-	char *builder_file;
 	char *text;
 
 	g_object_get (source, "plugin", &plugin, NULL);
-	builder_file = rb_find_plugin_data_file (plugin, "android-info.ui");
+	builder = rb_builder_load_plugin_file (G_OBJECT (plugin), "android-info.ui", NULL);
 	g_object_unref (plugin);
 
-	if (builder_file == NULL) {
-		g_warning ("Couldn't find android-info.ui");
-		return;
-	}
-
-	builder = rb_builder_load (builder_file, NULL);
-	g_free (builder_file);
-
-	if (builder == NULL) {
-		rb_debug ("Couldn't load android-info.ui");
-		return;
-	}
-
 	/* 'basic' tab stuff */
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "android-basic-info"));
