@@ -351,9 +351,9 @@ rb_audioscrobbler_user_init (RBAudioscrobblerUser *user)
 	user->priv = RB_AUDIOSCROBBLER_USER_GET_PRIVATE (user);
 
 	user->priv->soup_session =
-		soup_session_async_new_with_options (SOUP_SESSION_ADD_FEATURE_BY_TYPE,
-		                                     SOUP_TYPE_PROXY_RESOLVER_DEFAULT,
-		                                     NULL);
+		soup_session_new_with_options (SOUP_SESSION_ADD_FEATURE_BY_TYPE,
+					       SOUP_TYPE_PROXY_RESOLVER_DEFAULT,
+					       NULL);
 
 	user->priv->file_to_data_queue_map = g_hash_table_new_full (g_file_hash,
 	                                                            (GEqualFunc) g_file_equal,
